@@ -44,7 +44,7 @@ eval "`shunit_m`"
 set +e
 ( set -x
 ### -- test_maincode
-which bash && {
+type bash && {
 	bash --posix ./tests.code
 	_suc
 }
