@@ -36,12 +36,12 @@ title=*SH_bn* section=1 repnl=\040
 @name *SH_bn*
 @_brief alt-python same as alt-js
 @_syno
-	qy [infile/stdin] [-o outfile]
-	qy [-hHVs]
+	qy [-x] [-o outfile] [infile/stdin]
+	qy [-hHVsS]
 @tl_dr
 	@(code)@
  --- src.qy
- fn f(){
+ def f(){
  if(1==1){print(10)}
  }
  
@@ -61,6 +61,8 @@ title=*SH_bn* section=1 repnl=\040
 		@(list_o)
 	-hHV: usage, version
 	-s: output sample code
+	-S: output detail sample code
+	-x: output with debug mode
 	-o file: output dist (dfl@:stdout)
 		@()
 @_desc
@@ -78,9 +80,10 @@ title=*SH_bn* section=1 repnl=\040
 		@(code)--
 	(add 'try-except' blockcode)
 	~$ your_editor $(which qy)
-	_EL_W <- "else" / "el"	>>>  "else"/"el"/"try"/"except"
+	MY_TERM <- ":=" {_0 = "="}	>>>  "eq" { _0 = "=" }
 		@()--
 	see 'ped -h' help about peg-grammer.
+	you can also use cpp. see 'qy -s' sample.
 @exit_status suc/fail == 0/not0
 @notes	Python's grammar is inconsistent, and the API is changed with
  an idea, without any glance. I created 'qy' to save the conscience of
@@ -88,7 +91,7 @@ title=*SH_bn* section=1 repnl=\040
 
 @compat c compiler(posix-2001+), posix-shell
 @copyright	Copyright (C) 2022 Momi-g, AGPLv3+
-@_ver 2022-09-28 v1.0.1 (2022-09-27 v1.0.0)
+@_ver 2022-09-29 v1.0.4 (2022-09-27 v1.0.0)
 @_see -
 #SH_docE
 EEE
@@ -106,10 +109,11 @@ f_err(){
 f_usage(){
 cat << 'EEE'
 HowTo (*SH_bn*, alt-python, conv c-style code to python)
-opt: -hH(elp), -V(er), -s(ample), -o(utput file)
+opt: -hH(elp), -V(er), -s(ample), -x(debug), -o(utput file)
 ------
   ~$ qy -s	#>> output sample code
   ~$ qy -s| qy #>> conv code
+  ~$ qy -s| qy -x #>> debugmode
   
   ~$ src.qy | qy > src.py
   ~$ qy src.qy -o src.py	#same as above
@@ -141,43 +145,68 @@ f_verinfo(){
 
 f_sample(){
 	cat << 'EEE'	#|sed -e'1d;$d'
+/*tl_dr:
+~$ qy -s | gcc -E -C -P -nostdinc - -
+~$ qy -s | cpp -C -P -nostdinc | qy | tee a.py	#cpp then qy
+~$ python3 ./a.py	*/
+
+#define __i		__init__
+#define ismain(...)		(__name__ == "__main__")
+#define pl(fmt, ...)	print(fmt "\n" % (__VA_ARGS__) )
+#define el	else
+
+fn f(){ pl("f_called") }
+class cl(){	// any_doc_msg
+	num = 12
+	fn __i(self){ pl("gen_obj: %d", self.num) }
+}
+	//--maincode
+f()
+obj = cl()
+pl("%s %d", cl.__doc__, obj.num+1)
+if(0){}
+if( ismain() ){ pl("main_call") }
+el{ pl("req_call") }
+EEE
+	exit 0
+}
+
+
+f_sampleS(){
+	cat << 'EEE'	#|sed -e'1d;$d'
 # tl_dr:
-# ~$ qy -s 	#ck qy_code
-# ~$ qy -s | qy > a.py	#conv to python
-# ~$ python3 ./a.py		#exec test
+# ~$ qy -s | qy | tee a.py
+# ~$ python3 ./a.py
 
-###### sample code
-	#-- /*" mycode.qy */
-/*" mycode.qy */
+###### lit/cmt
+	# //hw
+//hw
 
-	#-- //lcmt
-//lcmt
+	# /* hw */
+/* hw */
 
+	# /*" mulit"x3 lits"*/
+/*" mulit""" lits"*/
 
-	#-- use(sys)
-use(sys)
+	# /*' mulit"'''" lits''*/
+/*' mulit"'''" lits''*/
 
-	#-- use(math.sqrt)
-use(math.sqrt)
-print( sqrt(121) )
+	# '''any'''
+'''any'''
 
-	#-- use(os.*)
-use(os.*)
-print(getpid() )
+######  token
+# ++ -- != ! && || := 
+#>> += 1 -= 1 !=  not   and   or  = 
 
-	#-- av=use(sys.argv)
-av = use(sys.argv)
-print(av[0])
-
-	#-- /*' hw */
-s = /*' hw */
-
-	#-- fn hw(n=1){ print(s, n) }
-fn hw(n=1){ print(s, n) }
+###### blk
+	
+	#decl:  fn/def/class XXX (){}
+	# fn hw(n=1){ print(10, n) }
+fn hw(n=1){ print(10, n) }
 
 """
 class cl(){
-	fn __i(self){ self.num = 10 }
+	fn __init__(self){ self.num = 10 }
 	num=0
 	def f(self){
 		self.num++
@@ -187,7 +216,7 @@ class cl(){
 }
 """
 class cl(){
-	fn __i(self){ self.num = 10 }
+	fn __init__(self){ self.num = 10 }
 	num=0
 	def f(self){
 		self.num++
@@ -196,78 +225,20 @@ class cl(){
 	fn ff(){ print("from cl") }
 }
 
-	#-- for(i in range(10)){ hw(i) }
-for(i in range(10)){ hw(i) }
-
 cl.ff()
 obj = cl()
 obj.f()
 
+	#--cond: 1st(){} + 2nd-(){}
+	# 1st: if/for/while/with/try, 2nd-: elif/else if/except/else/finally
+	# if(0){}else if(0){}else(){}
+if(0){}else if(0){}else(){}
 
-###### blk
+	#-- for(i in range(10)){ hw(i) }else{}if(0){}
+for(i in range(10)){ hw(i) }else{}if(0){}
 
-#-- fn f(){print("") fn ff(){print("gw") }}
-fn f(){print("") fn ff(){print("gw") }}
-
-#-- fn ff(){}, fn/class/def
-fn f(){}
-class cl(){}
-def f(){}
-
-#-- for(){}, for(x){...} >> for x: ...
-for(i in range(3)){}
-
-#-- if(){},if/else if/elseif/elif/ef	
-#-- else{}, else/el
-if(0){}
-
-ef(0){}
-el{}
-
-###### lit/cmt
-	#-- //hw
-//hw
-
-	#-- /* hw */
-/* hw */
-
-	#-- /*" mulit"x3 lits"*/
-/*" mulit""" lits"*/
-
-		#--/*' mulit"'''" lits''*/
-/*' mulit"'''" lits''*/
-
-	#-- '''any'''
-'''any'''
-
-###### token
-# ++ -- != ! && || := nil NuLL nOne true FALSE __i
-#>> += 1 -= 1 !=  not   and   or  = None None None True False  __init__
-
-###### import/eval/for(dic)/ismain
-if(0){
-	#-- m = use(aa.bb.cc)
-m = use(aa.bb.cc)
-	#-- use(aa.bb.cc)
-use(aa.bb.cc)
-	#-- use(aa.bb.*)
-use(aa.bb.*)
-}
-
-	#-- eval_("xxx")
-eval_("print('eval_() test')")
-print(e, "suc==null, nx is ERRtest\n\n")
-
-	#-- err: eval_("badcode")
-eval_("errtest_str")
-print(e)
-
-	#-- for( k,v in pairs(d) ){}
-d=locals()
-for( k,v in pairs(d) ){ print("pairs() test",k,v);break }
-
-	#-- ismain()
-if(ismain()){ print("ismain() test") }
+	#-- try{ hw(i) } except(Exception as e){hw(i)}
+try{ hw(i) }except(Exception as e){hw(i)}
 
 print("*SH_bn*, all ok")
 EEE
@@ -280,7 +251,10 @@ EEE
 )
 
 f_qypst(){
-#cat;return
+ [ "${flg#*x}" != "$flg" ] && {
+	 cat
+	 return
+ }
  awk ' BEGIN{s=""}
  $0~ /^\^\^\^/ { $0=substr($0,4); s=substr(s, 2) }
  $0~ /^\^\^/ { $0=substr($0,3); s=substr(s, 2);if(NF==0){$0="pass"}}
@@ -299,6 +273,7 @@ f_qypst(){
 
 *SH_bn*_main()(
 		:<<- 'CMT'
+	OPTIND=1
 	while getopts ":hHVQ" c; do case "$c" in				
 	[?:]) f_err "bad opt: $OPTARG, $*" ;;	
 	h) f_usage	;;
@@ -313,6 +288,7 @@ f_qypst(){
 	ass=""
 	ofile="/dev/stdout"
 	ifile="/dev/stdin"
+	flg=""
 	for ag in "$@"; do
 		[ "$ass" = 0 ] && { ifile="$ag"; break;}
 		[ -z "$ass" ] || { eval "$ass"; ass=""; continue;}
@@ -320,6 +296,8 @@ f_qypst(){
 		[ "${ag#-H}" != "$ag" ] && f_usageH
 		[ "${ag#-V}" != "$ag" ] && f_verinfo
 		[ "${ag#-s}" != "$ag" ] && f_sample
+		[ "${ag#-S}" != "$ag" ] && f_sampleS
+		[ "${ag#-x}" != "$ag" ] && flg="$flg"x && continue
 		[ "${ag#-o}" != "$ag" ] && {
 			ass='ofile="$ag"'
 			ag="${ag#..}"
@@ -341,12 +319,24 @@ f_qypst(){
 #SH_TSS
 test_cmd(){
 	cmd="*SH_bn*"
+	tmpf="*SH_bn*.tmp"
 	buf=`./$cmd -h`;	_suc 1
 	buf=`./$cmd -H`;	_suc 2
 	buf=`./$cmd -V`;	_suc 3
 	buf=`./$cmd -s`;	_suc 4
-	which python3 && {
-		python3 -c "$(./$cmd -s| ./$cmd )" >/dev/null
+	buf=`./$cmd -S`;	_suc 4
+	buf=`./$cmd -s|./$cmd -x`;	_suc 44
+	buf=`./$cmd -S|./$cmd -x`;	_suc 44
+
+	type gcc python3 && {
+		./$cmd -s |gcc -E -P -C -nostdinc - - |./$cmd  > $tmpf
+		python3 $tmpf >/dev/null
+		_suc 5
+	}
+
+	type python3 && {
+		./$cmd -S | ./$cmd > $tmpf 
+		python3 $tmpf >/dev/null
 		_suc 5
 	}
 	echo "ok: *SH_bn*_test_cmd"
@@ -366,6 +356,20 @@ test_22(){
 :<<'EEE'
  change log
  --
+2022-09-30  Momi-g	<dmy@dmy.dmy>
+
+	* qy.sh.c(qy.ped) : omit myfunc or ohter replace >> use CPP with DIY
+	
+	* qy.sh.c(qy.ped) : fix CMT peg syntax
+	
+	* qy.sh.c(f_sampleS) : add python+cpp hybrid sample code
+
+2022-09-29  Momi-g	<dmy@dmy.dmy>
+
+	* qy.sh.c(qy.ped) : rewrite AST. v1.0.2
+	
+	* qy.sh.c(qy) : add dbgopt -x
+
 2022-09-28  Momi-g	<dmy@dmy.dmy>
 
 	* qy.sh.c(qy.ped) : fix ':pass(nl)', '__i', 'for(x)' and other syntax
@@ -380,7 +384,6 @@ EEE
 
 #SH_ED
 
-
 #SH_OP _ a=`sed -ne "/${C}DF/!d;:l;n;/${C}DE/q;p;bl"<$R0`;eval "$a";set +e	#*/
 #SH_OP h $p"-tsbS:test/eg/.o/.so -LMP:leak,mem,prof -f:funcs -o:bldout	GPLv3+"	 #*/
 #SH_OP f sed -ne "/${C}DF/q;/;/d;/^[a-z].*)/p"<$R0|tr -d ' \t'|grep -F '()' #*/
